static

package
v0.0.0-...-03cefae Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2021 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Statics

type Statics struct {
	DTDFile string
	FS      fs.FS
	PAAFile string
}

Statics wraps the underlying fs.FS and provides hashed filenames for commonly used static files

func LoadStatics

func LoadStatics() (*Statics, error)

LoadStatics verifies that the embedded files are all present and fetches hashes for commonly used static files

Jump to