Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Statics ¶
Statics wraps the underlying fs.FS and provides hashed filenames for commonly used static files
func LoadStatics ¶
LoadStatics verifies that the embedded files are all present and fetches hashes for commonly used static files
Click to show internal directories.
Click to hide internal directories.